/* ////////////////////////////////////////////////////////////

File Name: ysairfoil_naca6_data.cpp
Copyright (c) 2017 Soji Yamakawa.  All rights reserved.
http://www.ysflight.com

Redistribution and use in source and binary forms, with or without modification, 
are permitted provided that the following conditions are met:

1. Redistributions of source code must retain the above copyright notice, 
   this list of conditions and the following disclaimer.

2. Redistributions in binary form must reproduce the above copyright notice, 
   this list of conditions and the following disclaimer in the documentation 
   and/or other materials provided with the distribution.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" 
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, 
THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR 
PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS 
BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR 
CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE 
GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) 
HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT 
LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT 
OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

//////////////////////////////////////////////////////////// */

#include "ysairfoil.h"

// Report R-84 pp. 3-14 not entered yet.

const AirfoilNACA6::Chord AirfoilNACA6::AirfoilData[]=
{
	{
		"63,4-020", // NACA Report 824 pp. 75
		{
			0,    0,    
			.5,   1.714,
			.75,  2.081,
			1.25, 2.638,
			2.5,  3.606,
			5.0,  4.947,
			7.5,  5.964,
			10.0, 6.800,
			15.0, 8.090,
			20.0, 9.006,
			25.0, 9.630,
			30.0, 9.955,
			35.0, 9.978,
			40.0, 9.765,
			45.0, 9.366,
			50.0, 8.819,
			55.0, 8.143,
			60.0, 7.351,
			65,   6.464,
			70,   5.496,
			75,   4.466,
			80,   3.401,
			85,   2.342,
			90,   1.348,
			95,   .501, 
			100,  0,    
		}
	},
	{
		"63-002", // NACA Report R84
		{
			0,    0,
			.5,   .158,
			.75,  .198,
			1.25, .254,
			2.5,  .352,
			5.0,  .489,
			7.5,  .590,
			10.0, .671,
			15.0, .796,
			20.0, .885,
			25.0, .946,
			30.0, .983,
			35.0, .999,
			40.0, .993,
			45.0, .965,
			50.0, .916,
			55.0, .950,
			60.0, .760,
			65,   .676,
			70,   .573,
			75,   .463,
			80,   .350,
			85,   .239,
			90,   .136,
			95,   .051,
			100,  0,
		}
	},
	{
		"63-003", // NACA Report R84
		{
			0,    0,
			.5,   .243,
			.75,  .300,
			1.25, .383,
			2.5,  .528,
			5.0,  .732,
			7.5,  .884,
			10.0, 1.006,
			15.0, 1.193,
			20.0, 1.327,
			25.0, 1.420,
			30.0, 1.476,
			35.0, 1.499,
			40.0, 1.489,
			45.0, 1.445,
			50.0, 1.371,
			55.0, 1.271,
			60.0, 1.149,
			65,   1.008,
			70,   .853,
			75,   .688,
			80,   .520,
			85,   .354,
			90,   .201,
			95,   .074,
			100,  0,
		}
	},
	{
		"63-004", // NACA Report R84
		{
			0,    0,
			.5,   .330,
			.75,  .404,
			1.25, .513,
			2.5,  .705,
			5.0,  .976,
			7.5,  1.178,
			10.0, 1.341,
			15.0, 1.590,
			20.0, 1.770,
			25.0, 1.894,
			30.0, 1.969,
			35.0, 2.000,
			40.0, 1.984,
			45.0, 1.924,
			50.0, 1.824,
			55.0, 1.689,
			60.0, 1.525,
			65,   1.336,
			70,   1.120,
			75,   .910,
			80,   .686,
			85,   .466,
			90,   .263,
			95,   .096,
			100,  0,
		}
	},
	{
		"63-005", // NACA Report R84
		{
			0,    0,
			.5,   .417,
			.75,  .506,
			1.25, .642,
			2.5,  .881,
			5.0,  1.220,
			7.5,  1.472,
			10.0, 1.676,
			15.0, 1.988,
			20.0, 2.213,
			25.0, 2.368,
			30.0, 2.462,
			35.0, 2.500,
			40.0, 2.478,
			45.0, 2.401,
			50.0, 2.274,
			55.0, 2.104,
			60.0, 1.897,
			65,   1.661,
			70,   1.401,
			75,   1.128,
			80,   .849,
			85,   .576,
			90,   .324,
			95,   .118,
			100,  0,
		}
	},
	{
		"63-006", // NACA Report 824 pp. 75
		{
			0,    0,    
			.5,   .503, 
			.75,  .609, 
			1.25, .771, 
			2.5,  1.057,
			5.0,  1.462,
			7.5,  1.766,
			10.0, 2.010,
			15.0, 2.386,
			20.0, 2.656,
			25.0, 2.841,
			30.0, 2.954,
			35.0, 3.000,
			40.0, 2.971,
			45.0, 2.877,
			50.0, 2.723,
			55.0, 2.517,
			60.0, 2.267,
			65,   1.982,
			70,   1.670,
			75,   1.342,
			80,   1.008,
			85,   .683, 
			90,   .383, 
			95,   .138, 
			100,  0,    
		}
	},
	{
		"63-009", // NACA Report 824 pp. 75
		{
			0,    0,    
			.5,   .749, 
			.75,  .906, 
			1.25, 1.151,
			2.5,  1.582,
			5.0,  2.196,
			7.5,  2.655,
			10.0, 3.024,
			15.0, 3.591,
			20.0, 3.997,
			25.0, 4.275,
			30.0, 4.442,
			35.0, 4.500,
			40.0, 4.447,
			45.0, 4.296,
			50.0, 4.056,
			55.0, 3.739,
			60.0, 3.358,
			65,   2.928,
			70,   2.458,
			75,   1.966,
			80,   1.471,
			85,   .990, 
			90,   .550, 
			95,   .196, 
			100,  0,    
		}
	},
	{
		"63-010", // NACA Report 824 pp. 76
		{
			0,    0,    
			.5,   .829, 
			.75,  1.004,
			1.25, 1.275,
			2.5,  1.756,
			5.0,  2.440,
			7.5,  2.950,
			10.0, 3.362,
			15.0, 3.994,
			20.0, 4.445,
			25.0, 4.753,
			30.0, 4.938,
			35.0, 5.000,
			40.0, 4.938,
			45.0, 4.766,
			50.0, 4.496,
			55.0, 4.140,
			60.0, 3.715,
			65,   3.234,
			70,   2.712,
			75,   2.166,
			80,   1.618,
			85,   1.088,
			90,   .604, 
			95,   .214, 
			100,  0,    
		}
	},
	{
		"63_1-012", // NACA Report 824 pp. 76
		{
			0,    0,    
			.5,   .985, 
			.75,  1.194,
			1.25, 1.519,
			2.5,  2.102,
			5.0,  2.925,
			7.5,  3.542,
			10.0, 4.039,
			15.0, 4.799,
			20.0, 5.342,
			25.0, 5.712,
			30.0, 5.930,
			35.0, 6.000,
			40.0, 5.920,
			45.0, 5.704,
			50.0, 5.370,
			55.0, 4.935,
			60.0, 4.420,
			65,   3.840,
			70,   3.210,
			75,   2.556,
			80,   1.902,
			85,   1.274,
			90,   .707, 
			95,   .250, 
			100,  0,    
		}
	},
	{
		"63_2-015", // NACA Report 824 pp. 76
		{
			0,    0.0,
			.5,   1.204,
			.75,  1.462,
			1.25, 1.878,
			2.5,  2.610,
			5.0,  3.648,
			7.5,  4.427,
			10.0, 5.055,
			15.0, 6.011,
			20.0, 6.693,
			25.0, 7.155,
			30.0, 7.421,
			35.0, 7.500,
			40.0, 7.386,
			45.0, 7.099,
			50.0, 6.665,
			55.0, 6.108,
			60.0, 5.453,
			65,   4.721,
			70,   3.934,
			75,   3.119,
			80,   2.310,
			85,   1.541,
			90,   .852,
			95,   .300,
			100,  0,
		}
	},
	{
		"63_3-018", // NACA Report 824 pp. 77
		{
			0,    0,    
			.5,   1.404,
			.75,  1.713,
			1.25, 2.217,
			2.5,  3.104,
			5.0,  4.362,
			7.5,  5.308,
			10.0, 6.068,
			15.0, 7.225,
			20.0, 8.048,
			25.0, 8.600,
			30.0, 8.913,
			35.0, 9.000,
			40.0, 8.845,
			45.0, 8.482,
			50.0, 7.942,
			55.0, 7.256,
			60.0, 6.455,
			65,   5.567,
			70,   4.622,
			75,   3.650,
			80,   2.691,
			85,   1.787,
			90,   .985, 
			95,   .348, 
			100,  0,    
		}
	},
	{
		"63_4-021", // NACA Report 824 pp. 77
		{
			0,    0,    
			.5,   1.583,
			.75,  1.937,
			1.25, 2.527,
			2.5,  3.577,
			5.0,  5.065,
			7.5,  6.182,
			10.0, 7.080,
			15.0, 8.441,
			20.0, 9.410,
			25.0, 10.05,
			30.0, 10.41,
			35.0, 10.50,
			40.0, 10.29,
			45.0, 9.854,
			50.0, 9.206,
			55.0, 8.390,
			60.0, 7.441,
			65,   6.396,
			70,   5.290,
			75,   4.160,
			80,   3.054,
			85,   2.021,
			90,   1.113,
			95,   .392, 
			100,  0,    
		}
	},
	{
		"64,2-015", // NACA Report 824 pp. 77
		{
			0,    0,    
			.5,   1.216,
			.75,  1.453,
			1.25, 1.829,
			2.5,  2.538,
			5.0,  3.514,
			7.5,  4.243,
			10.0, 4.838,
			15.0, 5.781,
			20.0, 6.464,
			25.0, 6.967,
			30.0, 7.307,
			35.0, 7.481,
			40.0, 7.480,
			45.0, 7.268,
			50.0, 6.850,
			55.0, 6.311,
			60.0, 5.670,
			65,   4.944,
			70,   4.158,
			75,   3.338,
			80,   2.506,
			85,   1.698,
			90,   .961, 
			95,   .351, 
			100,  0,    
		}
	},
	{
		"64-002", // NACA Report R84
		{
			0,    0,
			.5,   .149,
			.75,  .188,
			1.25, .246,
			2.5,  .344,
			5.0,  .480,
			7.5,  .575,
			10.0, .654,
			15.0, .775,
			20.0, .863,
			25.0, .928,
			30.0, .971,
			35.0, .995,
			40.0, .999,
			45.0, .976,
			50.0, .931,
			55.0, .867,
			60.0, .790,
			65,   .699,
			70,   .597,
			75,   .487,
			80,   .372,
			85,   .258,
			90,   .150,
			95,   .058,
			100,  .0,
		}
	},
	{
		"64-003", // NACA Report R84
		{
			0,    0,
			.5,   .235,
			.75,  .288,
			1.25, .372,
			2.5,  .515,
			5.0,  .712,
			7.5,  .856,
			10.0, .973,
			15.0, 1.156,
			20.0, 1.291,
			25.0, 1.389,
			30.0, 1.455,
			35.0, 1.491,
			40.0, 1.499,
			45.0, 1.463,
			50.0, 1.395,
			55.0, 1.298,
			60.0, 1.180,
			65,   1.043,
			70,   .889,
			75,   .724,
			80,   .553,
			85,   .382,
			90,   .221,
			95,   .084,
			100,  0,
		}
	},
	{
		"64-004", // NACA Report R84
		{
			0,    0,
			.5,   .322,
			.75,  .391,
			1.25, .500,
			2.5,  .685,
			5.0,  .943,
			7.5,  1.134,
			10.0, 1.290,
			15.0, 1.536,
			20.0, 1.717,
			25.0, 1.849,
			30.0, 1.938,
			35.0, 1.987,
			40.0, 1.997,
			45.0, 1.950,
			50.0, 1.857,
			55.0, 1.726,
			60.0, 1.567,
			65,   1.382,
			70,   1.177,
			75,   .957,
			80,   .729,
			85,   .503,
			90,   .290,
			95,   .110,
			100,  0,
		}
	},
	{
		"64-005", // NACA Report R84
		{
			0,    0,
			.5,   .408,
			.75,  .494,
			1.25, .627,
			2.5,  .854,
			5.0,  1.173,
			7.5,  1.412,
			10.0, 1.608,
			15.0, 1.916,
			20.0, 2.143,
			25.0, 2.310,
			30.0, 2.421,
			35.0, 2.483,
			40.0, 2.496,
			45.0, 2.435,
			50.0, 2.316,
			55.0, 2.152,
			60.0, 1.950,
			65,   1.717,
			70,   1.460,
			75,   1.186,
			80,   .902,
			85,   .621,
			90,   .357,
			95,   .134,
			100,  0,
		}
	},
	{
		"64-006", // NACA Report 824 pp. 78
		{
			0,    0,    
			.5,   .494, 
			.75,  .596, 
			1.25, .754, 
			2.5,  1.024,
			5.0,  1.405,
			7.5,  1.692,
			10.0, 1.928,
			15.0, 2.298,
			20.0, 2.572,
			25.0, 2.772,
			30.0, 2.907,
			35.0, 2.981,
			40.0, 2.995,
			45.0, 2.919,
			50.0, 2.775,
			55.0, 2.575,
			60.0, 2.331,
			65,   2.050,
			70,   1.740,
			75,   1.412,
			80,   1.072,
			85,   .737, 
			90,   .423, 
			95,   .157, 
			100,  0,    
		}
	},
	{
		"64-008", // NACA Report 824 pp. 78
		{
			0,    0,    
			.5,   .658, 
			.75,  .794, 
			1.25, 1.005,
			2.5,  1.365,
			5.0,  1.875,
			7.5,  2.259,
			10.0, 2.574,
			15.0, 3.069,
			20.0, 3.437,
			25.0, 3.704,
			30.0, 3.884,
			35.0, 3.979,
			40.0, 3.992,
			45.0, 3.883,
			50.0, 3.684,
			55.0, 3.411,
			60.0, 3.081,
			65,   2.704,
			70,   2.291,
			75,   1.854,
			80,   1.404,
			85,   .961, 
			90,   .550, 
			95,   .206, 
			100,  0,    
		}
	},
	{
		"64-009", // NACA Report 824 pp. 78
		{
			0,    0,    
			.5,   .739, 
			.75,  .892, 
			1.25, 1.128,
			2.5,  1.533,
			5.0,  2.109,
			7.5,  2.543,
			10.0, 2.898,
			15.0, 3.455,
			20.0, 3.868,
			25.0, 4.170,
			30.0, 4.373,
			35.0, 4.479,
			40.0, 4.490,
			45.0, 4.364,
			50.0, 4.136,
			55.0, 3.826,
			60.0, 3.452,
			65,   3.026,
			70,   2.561,
			75,   2.069,
			80,   1.564,
			85,   1.069,
			90,   .611, 
			95,   .227, 
			100,  0,    
		}
	},
	{
		"64-010", // NACA Report 824 pp. 79
		{
			0,    0,    
			.5,   .820, 
			.75,  .989, 
			1.25, 1.250,
			2.5,  1.701,
			5.0,  2.343,
			7.5,  2.826,
			10.0, 3.221,
			15.0, 3.842,
			20.0, 4.302,
			25.0, 4.639,
			30.0, 4.864,
			35.0, 4.980,
			40.0, 4.988,
			45.0, 4.843,
			50.0, 4.586,
			55.0, 4.238,
			60.0, 3.820,
			65,   3.345,
			70,   2.827,
			75,   2.281,
			80,   1.722,
			85,   1.176,
			90,   .671, 
			95,   .248, 
			100,  0,    
		}
	},
	{
		"64_1-012", // NACA Report 824 pp. 79
		{
			0,    0,    
			.5,   .978, 
			.75,  1.179,
			1.25, 1.490,
			2.5,  2.035,
			5.0,  2.810,
			7.5,  3.394,
			10.0, 3.871,
			15.0, 4.620,
			20.0, 5.173,
			25.0, 5.576,
			30.0, 5.844,
			35.0, 5.978,
			40.0, 5.981,
			45.0, 5.798,
			50.0, 5.480,
			55.0, 5.056,
			60.0, 4.548,
			65,   3.974,
			70,   3.350,
			75,   2.695,
			80,   2.029,
			85,   1.382,
			90,   .786, 
			95,   .288, 
			100,  0,    
		}
	},
	{
		"64_2-015", // NACA Report 824 pp. 79
		{
			0,    0,    
			.5,   1.208,
			.75,  1.456,
			1.25, 1.842,
			2.5,  2.528,
			5.0,  3.504,
			7.5,  4.240,
			10.0, 4.842,
			15.0, 5.785,
			20.0, 6.480,
			25.0, 6.985,
			30.0, 7.319,
			35.0, 7.482,
			40.0, 7.473,
			45.0, 7.224,
			50.0, 6.810,
			55.0, 6.266,
			60.0, 5.620,
			65,   4.895,
			70,   4.113,
			75,   3.296,
			80,   2.472,
			85,   1.677,
			90,   .950, 
			95,   .346, 
			100,  0,    
		}
	},
	{
		"64_3-018", // NACA Report 824 pp. 80
		{
			0,    0,    
			.5,   1.428,
			.75,  1.720,
			1.25, 2.177,
			2.5,  3.005,
			5.0,  4.186,
			7.5,  5.076,
			10.0, 5.803,
			15.0, 6.942,
			20.0, 7.782,
			25.0, 8.391,
			30.0, 8.789,
			35.0, 8.979,
			40.0, 8.952,
			45.0, 8.630,
			50.0, 8.114,
			55.0, 7.445,
			60.0, 6.658,
			65,   5.782,
			70,   4.842,
			75,   3.866,
			80,   2.888,
			85,   1.951,
			90,   1.101,
			95,   .400, 
			100,  0,    
		}
	},
	{
		"64_4-021", // NACA Report 824 pp. 80
		{
			0,    0,    
			.5,   1.646,
			.75,  1.985,
			1.25, 2.517,
			2.5,  3.485,
			5.0,  4.871,
			7.5,  5.915,
			10.0, 6.769,
			15.0, 8.108,
			20.0, 9.095,
			25.0, 9.80, 
			30.0, 10.26,
			35.0, 10.48,
			40.0, 10.43,
			45.0, 10.03,
			50.0, 9.404,
			55.0, 8.607,
			60.0, 7.678,
			65,   6.649,
			70,   5.549,
			75,   4.416,
			80,   3.287,
			85,   2.213,
			90,   1.245,
			95,   .449, 
			100,  0,    
		}
	},
	{
		"65,2-016", // NACA Report 824 pp. 80
		{
			0,    0,    
			.5,   1.202,
			.75,  1.423,
			1.25, 1.796,
			2.5,  2.507,
			5.0,  3.543,
			7.5,  4.316,
			10.0, 4.954,
			15.0, 5.958,
			20.0, 6.701,
			25.0, 7.252,
			30.0, 7.645,
			35.0, 7.892,
			40.0, 7.995,
			45.0, 7.938,
			50.0, 7.672,
			55.0, 7.184,
			60.0, 6.495,
			65,   5.647,
			70,   4.713,
			75,   3.738,
			80,   2.759,
			85,   1.817,
			90,   .982, 
			95,   .340, 
			100,  0,    
		}
	},
	{
		"65,2-023", // NACA Report 824 pp. 81
		{
			0,    0,    
			.5,   1.664,
			.75,  2.040,
			1.25, 2.628,
			2.5,  3.715,
			5.0,  5.300,
			7.5,  6.478,
			10.0, 7.433,
			15.0, 8.889,
			20.0, 9.917,
			25.0, 10.64,
			30.0, 11.14,
			35.0, 11.42,
			40.0, 11.49,
			45.0, 11.36,
			50.0, 10.94,
			55.0, 10.17,
			60.0, 9.108,
			65,   7.848,
			70,   6.461,
			75,   5.015,
			80,   3.618,
			85,   2.345,
			90,   1.258,
			95,   .439, 
			100,  0,    
		}
	},
	{
		"65,3-018", // NACA Report 824 pp. 81
		{
			0,    0,    
			.5,   1.324,
			.75,  1.599,
			1.25, 2.004,
			2.5,  2.728,
			5.0,  3.831,
			7.5,  4.701,
			10.0, 5.424,
			15.0, 6.568,
			20.0, 7.434,
			25.0, 8.093,
			30.0, 8.568,
			35.0, 8.868,
			40.0, 8.900,
			45.0, 8.916,
			50.0, 8.593,
			55.0, 8.045,
			60.0, 7.317,
			65,   6.450,
			70,   5.486,
			75,   4.456,
			80,   3.300,
			85,   2.325,
			90,   1.324,
			95,   .492, 
			100,  0,    
		}
	},
	{
		"65-002", // NACA Report R84
		{
			0,    0,
			.5,   .139,
			.75,  .165,
			1.25, .211,
			2.5,  .307,
			5.0,  .430,
			7.5,  .522,
			10.0, .600,
			15.0, .724,
			20.0, .818,
			25.0, .890,
			30.0, .943,
			35.0, .979,
			40.0, .997,
			45.0, .997,
			50.0, .974,
			55.0, .926,
			60.0, .856,
			65,   .768,
			70,   .668,
			75,   .556,
			80,   .435,
			85,   .308,
			90,   .183,
			95,   .072,
			100,  0,
		}
	},
	{
		"65-003", // NACA Report R84
		{
			0,    0,
			.5,   .220,
			.75,  .264,
			1.25, .334,
			2.5,  .469,
			5.0,  .649,
			7.5,  .788,
			10.0, .905,
			15.0, 1.091,
			20.0, 1.233,
			25.0, 1.341,
			30.0, 1.420,
			35.0, 1.472,
			40.0, 1.498,
			45.0, 1.495,
			50.0, 1.458,
			55.0, 1.383,
			60.0, 1.276,
			65,   1.144,
			70,   .991,
			75,   .822,
			80,   .641,
			85,   .453,
			90,   .269,
			95,   .105,
			100,  0,
		}
	},
	{
		"65-004", // NACA Report R84
		{
			0,    0,
			.5,   .307,
			.75,  .370,
			1.25, .465,
			2.5,  .632,
			5.0,  .870,
			7.5,  1.055,
			10.0, 1.212,
			15.0, 1.460,
			20.0, 1.650,
			25.0, 1.793,
			30.0, 1.897,
			35.0, 1.965,
			40.0, 1.998,
			45.0, 1.991,
			50.0, 1.940,
			55.0, 1.838,
			60.0, 1.693,
			65,   1.515,
			70,   1.309,
			75,   1.083,
			80,   .842,
			85,   .593,
			90,   .351,
			95,   .136,
			100,  0,
		}
	},
	{
		"65-005", // NACA Report R84
		{
			0,    0,
			.5,   .394,
			.75,  .475,
			1.25, .594,
			2.5,  .795,
			5.0,  1.090,
			7.5,  1.322,
			10.0, 1.518,
			15.0, 1.828,
			20.0, 2.066,
			25.0, 2.245,
			30.0, 2.375,
			35.0, 2.459,
			40.0, 2.498,
			45.0, 2.487,
			50.0, 2.420,
			55.0, 2.290,
			60.0, 2.106,
			65,   1.881,
			70,   1.623,
			75,   1.339,
			80,   1.038,
			85,   .729,
			90,   .430,
			95,   .165,
			100,  0,
		}
	},
	{
		"65-006", // NACA Report 824 pp. 81
		{
			0,    0,    
			.5,   .476, 
			.75,  .574, 
			1.25, .717, 
			2.5,  .956, 
			5.0,  1.310,
			7.5,  1.589,
			10.0, 1.824,
			15.0, 2.197,
			20.0, 2.482,
			25.0, 2.697,
			30.0, 2.852,
			35.0, 2.952,
			40.0, 2.998,
			45.0, 2.983,
			50.0, 2.900,
			55.0, 2.741,
			60.0, 2.518,
			65,   2.246,
			70,   1.935,
			75,   1.594,
			80,   1.233,
			85,   .865, 
			90,   .510, 
			95,   .195, 
			100,  0,    
		}
	},
	{
		"65-008", // NACA Report 824 pp. 82
		{
			0,    0,    
			.5,   .627, 
			.75,  .756, 
			1.25, .945, 
			2.5,  1.267,
			5.0,  1.745,
			7.5,  2.118,
			10.0, 2.432,
			15.0, 2.931,
			20.0, 3.312,
			25.0, 3.599,
			30.0, 3.805,
			35.0, 3.938,
			40.0, 3.998,
			45.0, 3.974,
			50.0, 3.857,
			55.0, 3.688,
			60.0, 3.337,
			65,   2.971,
			70,   2.553,
			75,   2.096,
			80,   1.617,
			85,   1.131,
			90,   .664, 
			95,   .252, 
			100,  0,    
		}
	},
	{
		"65-009", // NACA Report 824 pp. 82
		{
			0,    0,    
			.5,   .700, 
			.75,  .845, 
			1.25, 1.058,
			2.5,  1.421,
			5.0,  1.961,
			7.5,  2.383,
			10.0, 2.736,
			15.0, 3.299,
			20.0, 3.727,
			25.0, 4.050,
			30.0, 4.282,
			35.0, 4.431,
			40.0, 4.496,
			45.0, 4.469,
			50.0, 4.336,
			55.0, 4.086,
			60.0, 3.743,
			65,   3.328,
			70,   2.856,
			75,   2.342,
			80,   1.805,
			85,   1.260,
			90,   .738, 
			95,   .280, 
			100,  0,    
		}
	},
	{
		"65-010", // NACA Report 824 pp. 82
		{
			0,    0,    
			.5,   .772, 
			.75,  .932, 
			1.25, 1.169,
			2.5,  1.574,
			5.0,  2.177,
			7.5,  2.647,
			10.0, 3.040,
			15.0, 3.666,
			20.0, 4.143,
			25.0, 4.503,
			30.0, 4.760,
			35.0, 4.924,
			40.0, 4.996,
			45.0, 4.968,
			50.0, 4.812,
			55.0, 4.530,
			60.0, 4.146,
			65,   3.682,
			70,   3.156,
			75,   2.584,
			80,   1.987,
			85,   1.385,
			90,   .810, 
			95,   .306, 
			100,  0,    
		}
	},
	{
		"65_1-012", // NACA Report 824 pp. 83
		{
			0,    0,    
			.5,   .923, 
			.75,  1.109,
			1.25, 1.387,
			2.5,  1.875,
			5.0,  2.606,
			7.5,  3.172,
			10.0, 3.647,
			15.0, 4.402,
			20.0, 4.975,
			25.0, 5.406,
			30.0, 5.716,
			35.0, 5.912,
			40.0, 5.997,
			45.0, 5.949,
			50.0, 5.757,
			55.0, 5.412,
			60.0, 4.943,
			65,   4.381,
			70,   3.743,
			75,   3.059,
			80,   2.345,
			85,   1.630,
			90,   .947, 
			95,   .356, 
			100,  0,    
		}
	},
	{
		"65_2-015", // NACA Report 824 pp. 83
		{
			0,    0,    
			.5,   1.124,
			.75,  1.356,
			1.25, 1.702,
			2.5,  2.324,
			5.0,  3.245,
			7.5,  3.959,
			10.0, 4.555,
			15.0, 5.504,
			20.0, 6.223,
			25.0, 6.764,
			30.0, 7.152,
			35.0, 7.396,
			40.0, 7.498,
			45.0, 7.427,
			50.0, 7.168,
			55.0, 6.720,
			60.0, 6.118,
			65,   5.403,
			70,   4.600,
			75,   3.744,
			80,   2.858,
			85,   1.977,
			90,   1.144,
			95,   .428, 
			100,  0,    
		}
	},
	{
		"65_3-018", // NACA Report 824 pp. 83
		{
			0,    0,    
			.5,   1.337,
			.75,  1.608,
			1.25, 2.014,
			2.5,  2.751,
			5.0,  3.866,
			7.5,  4.733,
			10.0, 5.457,
			15.0, 6.606,
			20.0, 7.476,
			25.0, 8.129,
			30.0, 8.595,
			35.0, 8.886,
			40.0, 8.999,
			45.0, 8.901,
			50.0, 8.568,
			55.0, 8.008,
			60.0, 7.267,
			65,   6.395,
			70,   5.426,
			75,   4.396,
			80,   3.338,
			85,   2.295,
			90,   1.319,
			95,   .400, 
			100,  0,    
		}
	},
	{
		"65_4-021", // NACA Report 824 pp. 84
		{
			0,    0,    
			.5,   1.522,
			.75,  1.838,
			1.25, 2.301,
			2.5,  3.154,
			5.0,  4.472,
			7.5,  5.498,
			10.0, 6.352,
			15.0, 7.700,
			20.0, 8.720,
			25.0, 9.487,
			30.0, 10.03,
			35.0, 10.37,
			40.0, 10.49,
			45.0, 10.36,
			50.0, 9.952,
			55.0, 9.277,
			60.0, 8.390,
			65,   7.360,
			70,   6.224,
			75,   5.024,
			80,   3.800,
			85,   2.598,
			90,   1.484,
			95,   .546, 
			100,  0,    
		}
	},
	{
		"66,1-012", // NACA Report 824 pp. 84
		{
			0,    0,    
			.5,   .900, 
			.75,  1.083,
			1.25, 1.343,
			2.5,  1.803,
			5.0,  2.484,
			7.5,  3.019,
			10.0, 3.482,
			15.0, 4.214,
			20.0, 4.779,
			25.0, 5.218,
			30.0, 5.550,
			35.0, 5.786,
			40.0, 5.934,
			45.0, 5.998,
			50.0, 5.972,
			55.0, 5.844,
			60.0, 5.594,
			65,   5.165,
			70,   4.535,
			75,   3.789,
			80,   2.964,
			85,   2.098,
			90,   1.244,
			95,   .477, 
			100,  0,    
		}
	},
	{
		"66,2-015", // NACA Report 824 pp. 84
		{
			0,    0,    
			.5,   1.110,
			.75,  1.329,
			1.25, 1.645,
			2.5,  2.229,
			5.0,  3.086,
			7.5,  3.757,
			10.0, 4.337,
			15.0, 5.255,
			20.0, 5.964,
			25.0, 6.516,
			30.0, 6.933,
			35.0, 7.230,
			40.0, 7.415,
			45.0, 7.495,
			50.0, 7.460,
			55.0, 7.294,
			60.0, 6.961,
			65,   6.405,
			70,   5.597,
			75,   4.652,
			80,   3.616,
			85,   2.545,
			90,   1.488,
			95,   .560, 
			100,  0,    
		}
	},
	{
		"66,2-018", // NACA Report 824 pp. 85
		{
			0,    0,    
			.5,   1.438,
			.75,  1.730,
			1.25, 2.180,
			2.5,  2.938,
			5.0,  3.984,
			7.5,  4.804,
			10.0, 5.486,
			15.0, 6.541,
			20.0, 7.342,
			25.0, 7.957,
			30.0, 8.419,
			35.0, 8.741,
			40.0, 8.933,
			45.0, 8.998,
			50.0, 8.934,
			55.0, 8.719,
			60.0, 8.316,
			65,   7.629,
			70,   6.657,
			75,   5.523,
			80,   4.296,
			85,   3.027,
			90,   1.789,
			95,   .672, 
			100,  0,    
		}
	},
	{
		"66-006", // NACA Report 824 pp. 85
		{
			0,    0,    
			.5,   .461, 
			.75,  .554, 
			1.25, .693, 
			2.5,  .918, 
			5.0,  1.257,
			7.5,  1.524,
			10.0, 1.752,
			15.0, 2.119,
			20.0, 2.401,
			25.0, 2.618,
			30.0, 2.782,
			35.0, 2.899,
			40.0, 2.971,
			45.0, 3.000,
			50.0, 2.985,
			55.0, 2.925,
			60.0, 2.815,
			65,   2.611,
			70,   2.316,
			75,   1.953,
			80,   1.543,
			85,   1.107,
			90,   .665, 
			95,   .262, 
			100,  0,    
		}
	},
	{
		"66-008", // NACA Report 824 pp. 85
		{
			0,    0,    
			.5,   .610, 
			.75,  .735, 
			1.25, .919, 
			2.5,  1.219,
			5.0,  1.673,
			7.5,  2.031,
			10.0, 2.335,
			15.0, 2.826,
			20.0, 3.201,
			25.0, 3.490,
			30.0, 3.709,
			35.0, 3.865,
			40.0, 3.962,
			45.0, 4.000,
			50.0, 3.978,
			55.0, 3.896,
			60.0, 3.740,
			65,   3.459,
			70,   3.062,
			75,   2.574,
			80,   2.027,
			85,   1.447,
			90,   .864, 
			95,   .338, 
			100,  0,    
		}
	},
	{
		"66-009", // NACA Report 824 pp. 86
		{
			0,    0,    
			.5,   .687, 
			.75,  .824, 
			1.25, 1.030,
			2.5,  1.368,
			5.0,  1.880,
			7.5,  2.283,
			10.0, 2.626,
			15.0, 3.178,
			20.0, 3.601,
			25.0, 3.927,
			30.0, 4.173,
			35.0, 4.348,
			40.0, 4.457,
			45.0, 4.499,
			50.0, 4.475,
			55.0, 4.381,
			60.0, 4.204,
			65,   3.882,
			70,   3.428,
			75,   2.877,
			80,   2.263,
			85,   1.611,
			90,   .961, 
			95,   .374, 
			100,  0,    
		}
	},
	{
		"66-010", // NACA Report 824 pp. 86
		{
			0,    0,    
			.5,   .759, 
			.75,  .913, 
			1.25, 1.141,
			2.5,  1.516,
			5.0,  2.087,
			7.5,  2.536,
			10.0, 2.917,
			15.0, 3.530,
			20.0, 4.001,
			25.0, 4.363,
			30.0, 4.636,
			35.0, 4.832,
			40.0, 4.953,
			45.0, 5.000,
			50.0, 4.971,
			55.0, 4.865,
			60.0, 4.665,
			65,   4.302,
			70,   3.787,
			75,   3.176,
			80,   2.494,
			85,   1.773,
			90,   1.054,
			95,   .408, 
			100,  0,    
		}
	},
	{
		"66_1-012", // NACA Report 824 pp. 86
		{
			0,    0,    
			.5,   .906, 
			.75,  1.087,
			1.25, 1.358,
			2.5,  1.808,
			5.0,  2.496,
			7.5,  3.037,
			10.0, 3.496,
			15.0, 4.234,
			20.0, 4.801,
			25.0, 5.238,
			30.0, 5.568,
			35.0, 5.803,
			40.0, 5.947,
			45.0, 6.000,
			50.0, 5.965,
			55.0, 5.836,
			60.0, 5.588,
			65,   5.139,
			70,   4.515,
			75,   3.767,
			80,   2.944,
			85,   2.083,
			90,   1.234,
			95,   .474, 
			100,  0,    
		}
	},
	{
		"66_2-015",  // NACA Report 824 pp. 87
		{
			0,    0,    
			.5,   1.122,
			.75,  1.343,
			1.25, 1.675,
			2.5,  2.235,
			5.0,  3.100,
			7.5,  3.781,
			10.0, 4.358,
			15.0, 5.286,
			20.0, 5.995,
			25.0, 6.543,
			30.0, 6.956,
			35.0, 7.250,
			40.0, 7.430,
			45.0, 7.495,
			50.0, 7.450,
			55.0, 7.283,
			60.0, 6.959,
			65,   6.372,
			70,   5.576,
			75,   4.632,
			80,   3.598,
			85,   2.530,
			90,   1.489,
			95,   .566, 
			100,  0,    
		}
	},
	{
		"66_3-018",  // NACA Report 824 pp. 87
		{
			0,    0,    
			.5,   1.323,
			.75,  1.571,
			1.25, 1.952,
			2.5,  2.646,
			5.0,  3.690,
			7.5,  4.513,
			10.0, 5.210,
			15.0, 6.333,
			20.0, 7.188,
			25.0, 7.848,
			30.0, 8.346,
			35.0, 8.701,
			40.0, 8.918,
			45.0, 8.998,
			50.0, 8.942,
			55.0, 8.733,
			60.0, 8.323,
			65,   7.580,
			70,   6.597,
			75,   5.451,
			80,   4.206,
			85,   2.934,
			90,   1.714,
			95,   .646, 
			100,  0,    
		}
	},
	{
		"66_4-021",  // NACA Report 824 pp. 87
		{
			0,    0,    
			.5,   1.525,
			.75,  1.804,
			1.25, 2.240,
			2.5,  3.045,
			5.0,  4.269,
			7.5,  5.233,
			10.0, 6.052,
			15.0, 7.369,
			20.0, 8.376,
			25.0, 9.153,
			30.0, 9.738,
			35.0, 10.154,
			40.0, 10.407,
			45.0, 10.500,
			50.0, 10.434,
			55.0, 10.186,
			60.0, 9.692,
			65,   8.793,
			70,   7.610,
			75,   6.251,
			80,   4.796,
			85,   3.324,
			90,   1.924,
			95,   .717, 
			100,  0,    
		}
	},
	{
		"67,1-015",  // NACA Report 824 pp. 88
		{
			0,    0,    
			.5,   1.167,
			.75,  1.394,
			1.25, 1.764,
			2.5,  2.395,
			5.0,  3.245,
			7.5,  3.900,
			10.0, 4.433,
			15.0, 5.283,
			20.0, 5.940,
			25.0, 6.454,
			30.0, 6.854,
			35.0, 7.155,
			40.0, 7.359,
			45.0, 7.475,
			50.0, 7.497,
			55.0, 7.421,
			60.0, 7.231,
			65,   6.905,
			70,   6.402,
			75,   5.621,
			80,   4.540,
			85,   3.327,
			90,   2.021,
			95,   .788, 
			100,  0,    
		}
	},
	{
		"63A002", // NACA Report R84
		{
			0,    0,
			.5,   .159,
			.75,  .196,
			1.25, .251,
			2.5,  .350,
			5.0,  .486,
			7.5,  .587,
			10.0, .668,
			15.0, .790,
			20.0, .877,
			25.0, .938,
			30.0, .977,
			35.0, .996,
			40.0, .995,
			45.0, .974,
			50.0, .936,
			55.0, .880,
			60.0, .808,
			65,   .724,
			70,   .630,
			75,   .528,
			80,   .424,
			85,   .319,
			90,   .214,
			95,   .109,
			100,  .005,
		}
	},
	{
		"63A003", // NACA Report R84
		{
			0,    0,
			.5,   .242,
			.75,  .295,
			1.25, .377,
			2.5,  .524,
			5.0,  .727,
			7.5,  .878,
			10.0, .999,
			15.0, 1.183,
			20.0, 1.315,
			25.0, 1.408,
			30.0, 1.467,
			35.0, 1.495,
			40.0, 1.493,
			45.0, 1.461,
			50.0, 1.400,
			55.0, 1.316,
			60.0, 1.209,
			65,   1.083,
			70,   .940,
			75,   .788,
			80,   .633,
			85,   .476,
			90,   .319,
			95,   .163,
			100,  .007,
		}
	},
	{
		"63A004", // NACA Report R84
		{
			0,    0,
			.5,   .326,
			.75,  .396,
			1.25, .503,
			2.5,  .698,
			5.0,  .967,
			7.5,  1.167,
			10.0, 1.328,
			15.0, 1.576,
			20.0, 1.753,
			25.0, 1.878,
			30.0, 1.958,
			35.0, 1.995,
			40.0, 1.991,
			45.0, 1.946,
			50.0, 1.864,
			55.0, 1.750,
			60.0, 1.607,
			65,   1.439,
			70,   1.240,
			75,   1.046,
			80,   .840,
			85,   .632,
			90,   .424,
			95,   .217,
			100,  .009,
		}
	},
	{
		"63A005", // NACA Report R84
		{
			0,    0,
			.5,   .412,
			.75,  .496,
			1.25, .628,
			2.5,  .871,
			5.0,  1.207,
			7.5,  1.456,
			10.0, 1.658,
			15.0, 1.968,
			20.0, 2.191,
			25.0, 2.348,
			30.0, 2.450,
			35.0, 2.496,
			40.0, 2.488,
			45.0, 2.430,
			50.0, 2.327,
			55.0, 2.183,
			60.0, 2.003,
			65,   1.792,
			70,   1.555,
			75,   1.302,
			80,   1.045,
			85,   .786,
			90,   .528,
			95,   .270,
			100,  .012,
		}
	},
	{
		"63A006", // NACA Report 903 pp. 3
		{
			0,    0,
			.5,   .495,
			.75,  .595,
			1.25, .754,
			2.5,  1.045,
			5.0,  1.447,
			7.5,  1.747,
			10.0, 1.989,
			15.0, 2.362,
			20.0, 2.631,
			25.0, 2.820,
			30.0, 2.942,
			35.0, 2.996,
			40.0, 2.985,
			45.0, 2.914,
			50.0, 2.788,
			55.0, 2.613,
			60.0, 2.396,
			65,   2.143,
			70,   1.859,
			75,   1.556,
			80,   1.248,
			85,   .939,
			90,   .630,
			95,   .322,
			100,  .013,
		}
	},
	{
		"63A008", // NACA Report 903 pp. 3
		{
			0,    0,
			.5,   .658,
			.75,  .791,
			1.25, 1.003,
			2.5,  1.391,
			5.0,  1.930,
			7.5,  2.332,
			10.0, 2.656,
			15.0, 3.155,
			20.0, 3.515,
			25.0, 3.766,
			30.0, 3.926,
			35.0, 3.995,
			40.0, 3.978,
			45.0, 3.878,
			50.0, 3.705,
			55.0, 3.468,
			60.0, 3.176,
			65,   2.837,
			70,   2.457,
			75,   2.055,
			80,   1.647,
			85,   1.240,
			90,   .833,
			95,   .425,
			100,  .018,
		},
	},
	{
		"63A010", // NACA Report 903 pp. 3
		{
			0,    0,
			.5,   .816,
			.75,  .983,
			1.25, 1.250,
			2.5,  1.737,
			5.0,  2.412,
			7.5,  2.917,
			10.0, 3.324,
			15.0, 3.950,
			20.0, 4.400,
			25.0, 4.714,
			30.0, 4.913,
			35.0, 4.995,
			40.0, 4.968,
			45.0, 4.837,
			50.0, 4.613,
			55.0, 4.311,
			60.0, 3.943,
			65,   3.517,
			70,   3.044,
			75,   2.545,
			80,   2.046,
			85,   1.535,
			90,   1.030,
			95,   .525,
			100,  .021,
		},
	},
	{
		"63_1A012", // NACA Report 903 pp. 4
		{
			0,    0,
			.5,   .973,
			.75,  1.173,
			1.25, 1.492,
			2.5,  2.078,
			5.0,  2.895,
			7.5,  3.504,
			10.0, 3.994,
			15.0, 4.747,
			20.0, 5.287,
			25.0, 5.664,
			30.0, 5.901,
			35.0, 5.995,
			40.0, 5.957,
			45.0, 5.792,
			50.0, 5.517,
			55.0, 5.148,
			60.0, 4.700,
			65,   4.186,
			70,   3.621,
			75,   3.026,
			80,   2.426,
			85,   1.826,
			90,   1.225,
			95,   .625,
			100,  .025,
		},
	},
	{
		"63_2A015", // NACA Report 903 pp. 4
		{
			0,    0,
			.5,   1.203,
			.75,  1.448,
			1.25, 1.844,
			2.5,  2.579,
			5.0,  3.618,
			7.5,  4.382,
			10.0, 4.997,
			15.0, 5.942,
			20.0, 6.619,
			25.0, 7.091,
			30.0, 7.384,
			35.0, 7.496,
			40.0, 7.435,
			45.0, 7.215,
			50.0, 6.858,
			55.0, 6.387,
			60.0, 5.820,
			65,   5.173,
			70,   4.468,
			75,   3.731,
			80,   2.991,
			85,   2.252,
			90,   1.512,
			95,   .772,
			100,  .032,
		},
	},
	{
		"64A002", // NACA Report R84
		{
			0,    0,
			.5,   .153,
			.75,  .191,
			1.25, .245,
			2.5,  .341,
			5.0,  .473,
			7.5,  .571,
			10.0, .650,
			15.0, .769,
			20.0, .856,
			25.0, .921,
			30.0, .967,
			35.0, .993,
			40.0, 1.00,
			45.0, .987,
			50.0, .950,
			55.0, .895,
			60.0, .825,
			65,   .744,
			70,   .652,
			75,   .550,
			80,   .442,
			85,   .332,
			90,   .223,
			95,   .113,
			100,  .004,
		}
	},
	{
		"64A003", // NACA Report R84
		{
			0,    0,
			.5,   .235,
			.75,  .289,
			1.25, .369,
			2.5,  .510,
			5.0,  .706,
			7.5,  .851,
			10.0, .969,
			15.0, 1.148,
			20.0, 1.282,
			25.0, 1.380,
			30.0, 1.449,
			35.0, 1.480,
			40.0, 1.500,
			45.0, 1.478,
			50.0, 1.421,
			55.0, 1.337,
			60.0, 1.232,
			65,   1.110,
			70,   .971,
			75,   .818,
			80,   .657,
			85,   .494,
			90,   .331,
			95,   .169,
			100,  .007,
		}
	},
	{
		"64A004", // NACA Report R84
		{
			0,    0,
			.5,   .318,
			.75,  .388,
			1.25, .492,
			2.5,  .679,
			5.0,  .937,
			7.5,  1.129,
			10.0, 1.286,
			15.0, 1.526,
			20.0, 1.706,
			25.0, 1.839,
			30.0, 1.931,
			35.0, 1.985,
			40.0, 2.000,
			45.0, 1.967,
			50.0, 1.890,
			55.0, 1.778,
			60.0, 1.637,
			65,   1.472,
			70,   1.286,
			75,   1.082,
			80,   .868,
			85,   .652,
			90,   .438,
			95,   .223,
			100,  .009,
		}
	},
	{
		"64A005", // NACA Report R84
		{
			0,    0,
			.5,   .402,
			.75,  .487,
			1.25, .616,
			2.5,  .848,
			5.0,  1.167,
			7.5,  1.406,
			10.0, 1.602,
			15.0, 1.904,
			20.0, 2.131,
			25.0, 2.297,
			30.0, 2.413,
			35.0, 2.481,
			40.0, 2.500,
			45.0, 2.456,
			50.0, 2.358,
			55.0, 2.216,
			60.0, 2.038,
			65,   1.831,
			70,   1.597,
			75,   1.343,
			80,   1.077,
			85,   .811,
			90,   .544,
			95,   .278,
			100,  .011,
		}
	},
	{
		"64A006", // NACA Report 903 pp. 4
		{
			0,    0,
			.5,   .485,
			.75,  .585,
			1.25, .739,
			2.5,  1.016,
			5.0,  1.399,
			7.5,  1.684,
			10.0, 1.919,
			15.0, 2.283,
			20.0, 2.557,
			25.0, 2.757,
			30.0, 2.896,
			35.0, 2.977,
			40.0, 2.999,
			45.0, 2.945,
			50.0, 2.825,
			55.0, 2.653,
			60.0, 2.438,
			65,   2.188,
			70,   1.907,
			75,   1.602,
			80,   1.285,
			85,   .967,
			90,   .649,
			95,   .331,
			100,  .013,
		},
	},
	{
		"64A008", // NACA Report 903 pp. 5
		{
			0,    0,
			.5,   .646,
			.75,  .778,
			1.25, .983,
			2.5,  1.353,
			5.0,  1.863,
			7.5,  2.245,
			10.0, 2.559,
			15.0, 3.047,
			20.0, 3.414,
			25.0, 3.681,
			30.0, 3.866,
			35.0, 3.972,
			40.0, 3.998,
			45.0, 3.921,
			50.0, 3.757,
			55.0, 3.524,
			60.0, 3.234,
			65,   2.897,
			70,   2.521,
			75,   2.117,
			80,   1.698,
			85,   1.278,
			90,   .858,
			95,   .438,
			100,  .018,
		},
	},
	{
		"64A010", // NACA Report 903 pp. 5
		{
			0,    0,
			.5,   .804,
			.75,  .969,
			1.25, 1.225,
			2.5,  1.688,
			5.0,  2.324,
			7.5,  2.805,
			10.0, 3.199,
			15.0, 3.813,
			20.0, 4.272,
			25.0, 4.606,
			30.0, 4.837,
			35.0, 4.968,
			40.0, 4.995,
			45.0, 4.894,
			50.0, 4.684,
			55.0, 4.388,
			60.0, 4.021,
			65,   3.597,
			70,   3.127,
			75,   2.623,
			80,   2.103,
			85,   1.582,
			90,   1.063,
			95,   .541,
			100,  .021,
		},
	},
	{
		"64_1A012", // NACA Report 903 pp. 5
		{
			0,    0,
			.5,   .961,
			.75,  1.158,
			1.25, 1.464,
			2.5,  2.018,
			5.0,  2.788,
			7.5,  3.364,
			10.0, 3.839,
			15.0, 4.580,
			20.0, 5.132,
			25.0, 5.534,
			30.0, 5.809,
			35.0, 5.965,
			40.0, 5.993,
			45.0, 5.863,
			50.0, 5.605,
			55.0, 5.214,
			60.0, 4.801,
			65,   4.289,
			70,   3.721,
			75,   3.118,
			80,   2.500,
			85,   1.882,
			90,   1.263,
			95,   .644,
			100,  .025,
		},
	},
	{
		"64_2A015", // NACA Report 903 pp. 6
		{
			0,    0,
			.5,   1.193,
			.75,  1.436,
			1.25, 1.815,
			2.5,  2.508,
			5.0,  3.477,
			7.5,  4.202,
			10.0, 4.799,
			15.0, 5.732,
			20.0, 6.423,
			25.0, 6.926,
			30.0, 7.270,
			35.0, 7.463,
			40.0, 7.487,
			45.0, 7.313,
			50.0, 6.978,
			55.0, 6.517,
			60.0, 5.956,
			65,   5.311,
			70,   4.600,
			75,   3.847,
			80,   3.084,
			85,   2.321,
			90,   1.558,
			95,   .795,
			100,  .032,
		},
	},
	{
		"65A002", // NACA Report R84
		{
			0,    0,
			.5,   .140,
			.75,  .168,
			1.25, .214,
			2.5,  .312,
			5.0,  .436,
			7.5,  .527,
			10.0, .603,
			15.0, .724,
			20.0, .818,
			25.0, .890,
			30.0, .944,
			35.0, .980,
			40.0, .999,
			45.0, .999,
			50.0, .989,
			55.0, .938,
			60.0, .876,
			65,   .799,
			70,   .707,
			75,   .603,
			80,   .489,
			85,   .368,
			90,   .247,
			95,   .126,
			100,  .004,
		}
	},
	{
		"65A003", // NACA Report R84
		{
			0,    0,
			.5,   .223,
			.75,  .269,
			1.25, .342,
			2.5,  .479,
			5.0,  .656,
			7.5,  .793,
			10.0, .908,
			15.0, 1.091,
			20.0, 1.231,
			25.0, 1.339,
			30.0, 1.418,
			35.0, 1.471,
			40.0, 1.498,
			45.0, 1.498,
			50.0, 1.467,
			55.0, 1.404,
			60.0, 1.310,
			65,   1.193,
			70,   1.056,
			75,   .901,
			80,   .729,
			85,   .550,
			90,   .369,
			95,   .188,
			100,  .007,
		}
	},
	{
		"65A004", // NACA Report R84
		{
			0,    0,
			.5,   .304,
			.75,  .368,
			1.25, .469,
			2.5,  .647,
			5.0,  .875,
			7.5,  1.059,
			10.0, 1.213,
			15.0, 1.459,
			20.0, 1.645,
			25.0, 1.788,
			30.0, 1.892,
			35.0, 1.962,
			40.0, 1.997,
			45.0, 1.996,
			50.0, 1.954,
			55.0, 1.868,
			60.0, 1.743,
			65,   1.586,
			70,   1.402,
			75,   1.195,
			80,   .967,
			85,   .729,
			90,   .490,
			95,   .250,
			100,  .009,
		}
	},
	{
		"65A005", // NACA Report R84
		{
			0,    0,
			.5,   .385,
			.75,  .467,
			1.25, .595,
			2.5,  .815,
			5.0,  1.094,
			7.5,  1.326,
			10.0, 1.519,
			15.0, 1.826,
			20.0, 2.059,
			25.0, 2.237,
			30.0, 2.367,
			35.0, 2.453,
			40.0, 2.496,
			45.0, 2.494,
			50.0, 2.440,
			55.0, 2.331,
			60.0, 2.173,
			65,   1.976,
			70,   1.746,
			75,   1.487,
			80,   1.203,
			85,   .907,
			90,   .609,
			95,   .310,
			100,  .011,
		}
	},
	{
		"65A006", // NACA Report 903 pp. 6
		{
			0,    0,
			.5,   .464,
			.75,  .563,
			1.25, .718,
			2.5,  .981,
			5.0,  1.313,
			7.5,  1.591,
			10.0, 1.824,
			15.0, 2.194,
			20.0, 2.474,
			25.0, 2.687,
			30.0, 2.842,
			35.0, 2.945,
			40.0, 2.996,
			45.0, 2.992,
			50.0, 2.925,
			55.0, 2.793,
			60.0, 2.602,
			65,   2.364,
			70,   2.087,
			75,   1.775,
			80,   1.437,
			85,   1.083,
			90,   .727,
			95,   .370,
			100,  .013,
		},
	},
	{
		"65A008", // NACA Report 903 pp. 6
		{
			0,    0,
			.5,   .615,
			.75,  .746,
			1.25, .951,
			2.5,  1.303,
			5.0,  1.749,
			7.5,  2.120,
			10.0, 2.432,
			15.0, 2.926,
			20.0, 3.301,
			25.0, 3.585,
			30.0, 3.791,
			35.0, 3.928,
			40.0, 3.995,
			45.0, 3.988,
			50.0, 3.895,
			55.0, 3.714,
			60.0, 3.456,
			65,   3.135,
			70,   2.763,
			75,   2.348,
			80,   1.898,
			85,   1.430,
			90,   .960,
			95,   .489,
			100,  .018,
		},
	},
	{
		"65A010", // NACA Report 903 pp. 7
		{
			0,    0,
			.5,   .765,
			.75,  .928,
			1.25, 1.183,
			2.5,  1.623,
			5.0,  2.182,
			7.5,  2.650,
			10.0, 3.040,
			15.0, 3.658,
			20.0, 4.127,
			25.0, 4.483,
			30.0, 4.742,
			35.0, 4.912,
			40.0, 4.995,
			45.0, 4.983,
			50.0, 4.863,
			55.0, 4.632,
			60.0, 4.304,
			65,   3.899,
			70,   3.432,
			75,   2.912,
			80,   2.352,
			85,   1.771,
			90,   1.188,
			95,   .604,
			100,  .021,
		},
	},
	{
		"65_1A012", // NACA Report 903 pp. 7
		{
			0,    0,
			.5,   .913,
			.75,  1.106,
			1.25, 1.414,
			2.5,  1.942,
			5.0,  2.614,
			7.5,  3.176,
			10.0, 3.647,
			15.0, 4.392,
			20.0, 4.956,
			25.0, 5.383,
			30.0, 5.693,
			35.0, 5.897,
			40.0, 5.995,
			45.0, 5.977,
			50.0, 5.828,
			55.0, 5.544,
			60.0, 5.143,
			65,   4.654,
			70,   4.091,
			75,   3.467,
			80,   2.798,
			85,   2.106,
			90,   1.413,
			95,   .719,
			100,  .025,
		},
	},
	{
		"65_2A015", // NACA Report 903 pp. 7
		{
			0,    0,
			.5,   1.131,
			.75,  1.371,
			1.25, 1.750,
			2.5,  2.412,
			5.0,  3.255,
			7.5,  3.962,
			10.0, 4.553,
			15.0, 5.488,
			20.0, 6.198,
			25.0, 6.734,
			30.0, 7.122,
			35.0, 7.376,
			40.0, 7.496,
			45.0, 7.467,
			50.0, 7.269,
			55.0, 6.903,
			60.0, 6.393,
			65,   5.772,
			70,   5.063,
			75,   4.282,
			80,   3.451,
			85,   2.598,
			90,   1.743,
			95,   .887,
			100,  .032,
		},
	},
	{
		"747A015",  // NACA Report 824 pp. 88
		{
			0,    0,    
			.5,   1.199,
			.75,  1.435,
			1.25, 1.801,
			2.5,  2.462,
			5.0,  3.419,
			7.5,  4.143,
			10.0, 4.743,
			15.0, 5.684,
			20.0, 6.384,
			25.0, 6.898,
			30.0, 7.253,
			35.0, 7.454,
			40.0, 7.494,
			45.0, 7.316,
			50.0, 7.003,
			55.0, 6.584,
			60.0, 6.064,
			65,   5.449,
			70,   4.738,
			75,   3.921,
			80,   3.020,
			85,   2.086,
			90,   1.193,
			95,   .443, 
			100,  0,    
		}
	},
	{
		(char *)0,
		{0.0}
	}
};





// Modified mean line: Make 85% and aft straight?  (Rep 903)

// See Report 824 pp. 5.  Second paragraph of the left column.
// It explains how to derive NACA xy mean line fron NACA 62,63,64,65,66, and 67.
// NACA aX mean line can be obtained by scaling NACA bX mean line by b:a ratio.
// Implies that the tables can multiplied into NACA ?2, ?3, ?4, ?5, ?6, and ?7.

// What about 3-digit mean lines then???

// Mean line data: Report 824 pp.90-
const AirfoilNACA6::Chord AirfoilNACA6::MeanLineAData[]=
{
	{
		"a=0.0",
		{
			0,    0,
			.5,   .460,
			.75,  .641,
			1.25, .964,
			2.5,  1.641,
			5.0,  2.693,
			7.5,  3.507,
			10.0, 4.161,
			15.0, 5.124,
			20.0, 5.747,
			25.0, 6.114,
			30.0, 6.277,
			35.0, 6.273,
			40.0, 6.130,
			45.0, 5.871,
			50.0, 5.516,
			55.0, 5.081,
			60.0, 4.581,
			65,   4.032,
			70,   3.445,
			75,   2.836,
			80,   2.217,
			85,   1.604,
			90,   1.013,
			95,   .467,
			100,  0,
		}
	},
	{
		"a=0.1",
		{
			0,     0,
			.5,   .440,
			.75,  .616,
			1.25, .933,
			2.5,  1.608,
			5.0,  2.689,
			7.5,  3.551,
			10.0, 4.253,
			15.0, 5.261,
			20.0, 5.905,
			25.0, 6.282,
			30.0, 6.449,
			35.0, 6.443,
			40.0, 6.296,
			45.0, 6.029,
			50.0, 5.664,
			55.0, 5.218,
			60.0, 4.706,
			65,   4.142,
			70,   3.541,
			75,   2.916,
			80,   2.281,
			85,   1.652,
			90,   1.045,
			95,   .482,
			100,  0,
		}
	},
	{
		"a=0.2",
		{
			0,    0,
			.5,   .414,
			.75,  .851,
			2.5,  1.530,
			5.0,  2.583,
			7.5,  3.443,
			10.0, 4.169,
			15.0, 5.317,
			20.0, 6.117,
			25.0, 6.572,
			30.0, 6.777,
			35.0, 6.789,
			40.0, 6.646,
			45.0, 6.373,
			50.0, 5.994,
			55.0, 5.527,
			60.0, 4.989,
			65,   4.396,
			70,   3.762,
			75,   3.102,
			80,   2.431,
			85,   1.764,
			90,   1.119,
			95,   .518, 
			100,  0,
		}
	},
	{
		"a=0.3",
		{
			0,    0,
			.5,   .389,
			.75,  .546,
			1.25, .832,
			2.5,  1.448,
			5.0,  2.458,
			7.5,  3.293,
			10.0, 4.008,
			15.0, 5.172,
			20.0, 6.052,
			25.0, 6.685,
			30.0, 7.072,
			35.0, 7.1759,
			40.0, 7.0749,
			45.0, 6.8169,
			50.0, 6.4339,
			55.0, 5.949,
			60.0, 5.383,
			65,   4.753,
			70,   4.076,
			75,   3.368,
			80,   2.645,
			85,   1.924,
			90,   1.224,
			95,   .570,
			100,  0,
		}
	},
	{
		"a=0.4",
		{
			0,    0,
			0.5,  .366,
			.75,  .514,
			1.25, .784,
			2.5,  1.367,
			1.0,  2.330,
			7.5,  3.131,
			10.0, 3.824,
			15.0, 4.968,
			20.0, 5.862,
			25.0, 6.546,
			30.0, 7.039,
			35.0, 7.343,
			40.0, 7.439,
			45.0, 7.275,
			50.0, 6.929,
			55.0, 6.449,
			60.0, 5.864,
			65,   5.199,
			70,   4.475,
			75,   3.709,
			80,   2.922,
			85,   2.132,
			90,   1.361,
			95,   .636,
			100,  0,
		}
	},
	{
		"a=0.5",
		{
			0,    0,
			.5,   .345,
			.75,  .485,
			1.25, .735,
			2.5,  1.295,
			5.0,  2.205,
			7.5,  2.970,
			10.0, 3.630,
			15.0, 4.740,
			20.0, 5.620,
			25.0, 6.310,
			30.0, 6.840,
			35.0, 7.215,
			40.0, 7.430,
			45.0, 7.490,
			50.0, 7.350,
			55.0, 6.965,
			60.0, 6.405,
			65,   5.725,
			70,   4.955,
			75,   4.130,
			80,   3.265,
			85,   2.395,
			90,   1.535,
			95,   .720,
			100,  0,
		}
	},
	{
		"a=0.6",
		{
			0,    0,
			.5,   .325,
			.75,  .455,
			1.25, .695,
			2.5,  1.220,
			5.0,  2.080,
			7.5,  2.805,
			10.0, 3.435,
			15.0, 4.495,
			20.0, 5.345,
			25.0, 6.035,
			30.0, 6.570,
			35.0, 6.965,
			40.0, 7.235,
			45.0, 7.370,
			50.0, 7.370,
			55.0, 7.220,
			60.0, 6.880,
			65,   6.275,
			70,   5.505,
			75,   4.630,
			80,   3.695,
			85,   2.720,
			90,   1.755,
			95,   .825,
			100,  0,
		}
	},
	{
		"a=0.7",
		{
			0,    0,
			.5,   .305,
			.75,  .425,
			1.25, .655,
			2.5,  1.160,
			5.0,  1.955,
			7.5,  2.645,
			10.0, 3.240,
			15.0, 4.245,
			20.0, 5.060,
			25.0, 5.715,
			30.0, 6.240,
			40.0, 6.925,
			45.0, 7.095,
			50.0, 7.155,
			55.0, 7.090,
			60.0, 6.900,
			65,   6.565,
			70,   6.030,
			75,   5.205,
			80,   4.215,
			85,   3.140,
			90,   2.035,
			95,   .965,
			100,  0,
		}
	},
	{
		"a=0.8",
		{
			0,    0,
			.5,   .287,
			.75,  .404,
			1.25, .616,
			2.5,  1.077,
			5.0,  1.841,
			7.5,  2.483,
			10.0, 3.043,
			15.0, 3.985,
			20.0, 4.748,
			25.0, 5.367,
			30.0, 5.863,
			35.0, 6.248,
			40.0, 6.528,
			45.0, 6.709,
			50.0, 6.790,
			55.0, 6.770,
			60.0, 6.644,
			65,   6.405,
			70,   6.037,
			75,   5.514,
			80,   4.771,
			85,   3.683,
			90,   2.435,
			95,   1.163,
			100,  0,
		}
	},
	{
		"a=0.9",
		{
			0,    0,
			.5,   .269,
			.75,  .379,
			1.25, .577,
			2.5,  1.008,
			5.0,  1.720,
			7.5,  2.316,
			10.0, 2.835,
			15.0, 3.707,
			20.0, 4.410,
			25.0, 4.980,
			30.0, 5.435,
			35.0, 5.787,
			40.0, 6.045,
			45.0, 6.212,
			50.0, 6.290,
			55.0, 6.279,
			60.0, 6.178,
			65,   5.981,
			70,   5.681,
			75,   5.265,
			80,   4.714,
			85,   3.987,
			90,   2.984,
			95,   1.503,
			100,  0,
		}
	},
	{
		"a=1.0",
		{
			0,    0,
			.5,   .250,
			.75,  .350,
			1.25, .535,
			2.5,  .930,
			5.0,  1.580,
			7.5,  2.120,
			10.0, 2.585,
			15.0, 3.365,
			20.0, 3.980,
			25.0, 4.475,
			30.0, 4.860,
			35.0, 5.150,
			40.0, 5.355,
			45.0, 5.475,
			50.0, 5.515,
			55.0, 5.475,
			60.0, 5.355,
			65,   5.150,
			70,   4.860,
			75,   4.475,
			80,   3.980,
			85,   3.365,
			90,   2.585,
			95,   1.580,
			100,  0,
		}
	},
};

const AirfoilNACA6::Chord AirfoilNACA6::MeanLineLabelData[]=
{
	{
		"MeanLine62",
		{
			0,    0,
			1.25, .726,
			2.5,  1.406,
			5.0,  2.625,
			7.5,  3.656,
			10.0, 4.500,
			15.0, 5.625,
			20.0, 6.000,
			25.0, 5.977,
			30.0, 5.906,
			40.0, 5.625,
			50.0, 5.156,
			60.0, 4.500,
			70,   3.656,
			80,   2.625,
			90,   1.406,
			95,   .727,
			100,  0,
		}
	},
	{
		"MeanLine63",
		{
			0,    0,
			1.25, .489,
			2.5,  .958,
			5.0,  1.833,
			7.5,  2.625,
			10.0, 3.333,
			15.0, 4.500,
			20.0, 5.333,
			25.0, 5.833,
			30.0, 6.000,
			40.0, 5.878,
			50.0, 5.510,
			60.0, 4.898,
			70,   4.041,
			80,   2.939,
			90,   1.592,
			95,   .827,
			100,  0,
		}
	},
	{
		"MeanLine64",
		{
			0,    0,
			1.25, .369,
			2.5,  .726,
			5.0,  1.406,
			7.5,  2.039,
			10.0, 2.625,
			15.0, 3.656,
			20.0, 4.500,
			25.0, 5.156,
			30.0, 5.625,
			40.0, 6.000,
			50.0, 5.833,
			60.0, 5.333,
			70,   4.500,
			80,   3.333,
			90,   1.833,
			95,   .958,
			100,  0,
		}
	},
	{
		"MeanLine65",
		{
			0,    0,
			1.25, .296,
			2.5,  .585,
			5.0,  1.140,
			7.5,  1.665,
			10.0, 2.160,
			15.0, 3.060,
			20.0, 3.840,
			25.0, 4.500,
			30.0, 5.040,
			40.0, 5.760,
			50.0, 6.000,
			60.0, 5.760,
			70,   5.040,
			80,   3.840,
			90,   2.160,
			95,   1.140,
			100,  0,
		}
	},
	{
		"MeanLine66",
		{
			0,    0,
			1.25, .247,
			2.5,  .490,
			5.0,  .958,
			7.5,  1.406,
			10.0, 1.833,
			15.0, 2.625,
			20.0, 3.333,
			25.0, 3.958,
			30.0, 4.500,
			40.0, 5.333,
			50.0, 5.833,
			60.0, 6.000,
			70,   5.625,
			80,   4.500,
			90,   2.625,
			95,   1.406,
			100,  0,
		}
	},
	{
		"MeanLine67",
		{
			0,    0,
			1.25, .212,
			2.5,  .421,
			5.0,  .827,
			7.5,  1.217,
			10.0, 1.592,
			15.0, 2.296,
			20.0, 2.939,
			25.0, 3.520,
			30.0, 4.041,
			40.0, 4.898,
			50.0, 5.510,
			60.0, 5.878,
			70,   6.000,
			80,   5.333,
			90,   3.333,
			95,   1.833,
			100,  0,
		}
	},
	{
		"MeanLine210",
		{
			0,    0,
			1.25, .596,
			2.5,  .928,
			5.0,  1.114,
			7.5,  1.087,
			10.0, 1.058,
			15.0, .999,
			20.0, .940,
			25.0, .881,
			30.0, .823,
			40.0, .705,
			50.0, .588,
			60.0, .470,
			70,   .353,
			80,   .235,
			90,   .118,
			95,   .059,
			100,  0,
		}
	},
	{
		"MeanLine220",
		{
			0,    0,
			1.25, .442,
			2.5,  .793,
			5.0,  1.257,
			7.5,  1.479,
			10.0, 1.535,
			15.0, 1.463,
			20.0, 1.377,
			25.0, 1.291,
			30.0, 1.205,
			40.0, 1.033,
			50.0, .861,
			60.0, .689,
			70,   .516,
			80,   .344,
			90,   .172,
			95,   .086,
			100,  0,
		}
	},
	{
		"MeanLine230",
		{
			0,    0,
			1.25, .357,
			2.5,  .666,
			5.0,  1.155,
			7.5,  1.492,
			10.0, 1.701,
			15.0, 1.838,
			20.0, 1.767,
			25.0, 1.656,
			30.0, 1.546,
			40.0, 1.325,
			50.0, 1.104,
			60.0, .883,
			70,   .662,
			80,   .442,
			90,   .221,
			95,   .110,
			100,  0,
		}
	},
	{
		"MeanLine240",
		{
			0,    0,
			1.25, .301,
			2.5,  .572,
			5.0,  1.035,
			7.5,  1.397,
			10.0, 1.671,
			15.0, 1.991,
			20.0, 2.079,
			25.0, 2.018,
			30.0, 1.890,
			40.0, 1.620,
			50.0, 1.350,
			60.0, 1.080,
			70,   .810,
			80,   .540,
			90,   .270,
			95,   .135,
			100,  0,
		}
	},
	{
		"MeanLine250",
		{
			0,    0,
			1.25, .258,
			2.5,  .498,
			5.0,  .922,
			7.5,  1.277,
			10.0, 1.570,
			15.0, 1.982,
			20.0, 2.199,
			25.0, 2.263,
			30.0, 2.212,
			40.0, 1.931,
			50.0, 1.609,
			60.0, 1.287,
			70,   .965,
			80,   .644,
			90,   .322,
			95,   .161,
			100,  0,
		}
	},
	{
		NULL,
		{0}
	}
};
